@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/12/16 11:28
+Date: 2021/7/15 19:27
 Desc: 新浪财经-债券-沪深可转债-实时行情数据和历史行情数据
 http://vip.stock.finance.sina.com.cn/mkt/#hskzz_z
 """
@@ -25,7 +25,7 @@ from mssdk.stock.cons import hk_js_decode
 
 def _get_zh_bond_hs_cov_page_count() -> int:
     """
-    行情中心首页-债券-沪深可转债的总页数
+    新浪财经-行情中心-债券-沪深可转债的总页数
     http://vip.stock.finance.sina.com.cn/mkt/#hskzz_z
     :return: 总页数
     :rtype: int
@@ -33,8 +33,8 @@ def _get_zh_bond_hs_cov_page_count() -> int:
     params = {
         "node": "hskzz_z",
     }
-    res = requests.get(zh_sina_bond_hs_cov_count_url, params=params)
-    page_count = int(re.findall(re.compile(r"\d+"), res.text)[0]) / 80
+    r = requests.get(zh_sina_bond_hs_cov_count_url, params=params)
+    page_count = int(re.findall(re.compile(r"\d+"), r.text)[0]) / 80
     if isinstance(page_count, int):
         return page_count
     else:
@@ -43,7 +43,7 @@ def _get_zh_bond_hs_cov_page_count() -> int:
 
 def bond_zh_hs_cov_spot() -> pd.DataFrame:
     """
-    新浪财经-债券-沪深可转债的实时行情数据, 大量抓取容易封IP
+    新浪财经-债券-沪深可转债的实时行情数据; 大量抓取容易封IP
     http://vip.stock.finance.sina.com.cn/mkt/#hskzz_z
     :return: 所有沪深可转债在当前时刻的实时行情数据
     :rtype: pandas.DataFrame
@@ -51,7 +51,7 @@ def bond_zh_hs_cov_spot() -> pd.DataFrame:
     big_df = pd.DataFrame()
     page_count = _get_zh_bond_hs_cov_page_count()
     zh_sina_bond_hs_payload_copy = zh_sina_bond_hs_cov_payload.copy()
-    for page in tqdm(range(1, page_count + 1)):
+    for page in tqdm(range(1, page_count + 1), leave=False):
         zh_sina_bond_hs_payload_copy.update({"page": page})
         res = requests.get(zh_sina_bond_hs_cov_url, params=zh_sina_bond_hs_payload_copy)
         data_json = demjson.decode(res.text)
@@ -59,16 +59,16 @@ def bond_zh_hs_cov_spot() -> pd.DataFrame:
     return big_df
 
 
-def bond_zh_hs_cov_daily(symbol: str = "sh113542") -> pd.DataFrame:
+def bond_zh_hs_cov_daily(symbol: str = "sz123111") -> pd.DataFrame:
     """
-    新浪财经-债券-沪深可转债的历史行情数据, 大量抓取容易封IP
+    新浪财经-债券-沪深可转债的历史行情数据, 大量抓取容易封 IP
     http://vip.stock.finance.sina.com.cn/mkt/#hskzz_z
     :param symbol: 沪深可转债代码; e.g., sh010107
     :type symbol: str
     :return: 指定沪深可转债代码的日 K 线数据
     :rtype: pandas.DataFrame
     """
-    res = requests.get(
+    r = requests.get(
         zh_sina_bond_hs_cov_hist_url.format(
             symbol, datetime.datetime.now().strftime("%Y_%m_%d")
         )
@@ -76,12 +76,10 @@ def bond_zh_hs_cov_daily(symbol: str = "sh113542") -> pd.DataFrame:
     js_code = py_mini_racer.MiniRacer()
     js_code.eval(hk_js_decode)
     dict_list = js_code.call(
-        "d", res.text.split("=")[1].split(";")[0].replace('"', "")
+        "d", r.text.split("=")[1].split(";")[0].replace('"', "")
     )  # 执行js解密代码
     data_df = pd.DataFrame(dict_list)
-    data_df.index = pd.to_datetime(data_df["date"])
-    del data_df["date"]
-    data_df = data_df.astype("float")
+    data_df['date'] = pd.to_datetime(data_df["date"]).dt.date
     return data_df
 
 
@@ -197,9 +195,8 @@ def bond_cov_comparison() -> pd.DataFrame:
     :return: 可转债比价表数据
     :rtype: pandas.DataFrame
     """
-    url = "http://77.push2.eastmoney.com/api/qt/clist/get"
+    url = "http://16.push2.eastmoney.com/api/qt/clist/get"
     params = {
-        "cb": "jQuery112406285914172501668_1590386857513",
         "pn": "1",
         "pz": "5000",
         "po": "1",
@@ -214,12 +211,15 @@ def bond_cov_comparison() -> pd.DataFrame:
     }
     r = requests.get(url, params=params)
     text_data = r.text
-    json_data = demjson.decode(text_data[text_data.find("{") : -2])
+    json_data = demjson.decode(text_data)
     temp_df = pd.DataFrame(json_data["data"]["diff"])
+    temp_df.reset_index(inplace=True)
+    temp_df['index'] = range(1, len(temp_df)+1)
     temp_df.columns = [
+        "序号",
         "_",
-        "最新价",
-        "涨跌幅",
+        "转债最新价",
+        "转债涨跌幅",
         "转债代码",
         "_",
         "转债名称",
@@ -227,8 +227,8 @@ def bond_cov_comparison() -> pd.DataFrame:
         "_",
         "纯债价值",
         "_",
-        "_",
-        "涨跌幅",
+        "正股最新价",
+        "正股涨跌幅",
         "_",
         "正股代码",
         "_",
@@ -245,15 +245,15 @@ def bond_cov_comparison() -> pd.DataFrame:
     ]
     temp_df = temp_df[
         [
-            "最新价",
-            "涨跌幅",
+            "序号",
             "转债代码",
             "转债名称",
-            "上市日期",
-            "纯债价值",
-            "涨跌幅",
+            "转债最新价",
+            "转债涨跌幅",
             "正股代码",
             "正股名称",
+            "正股最新价",
+            "正股涨跌幅",
             "转股价",
             "转股价值",
             "转股溢价率",
@@ -261,7 +261,9 @@ def bond_cov_comparison() -> pd.DataFrame:
             "回售触发价",
             "强赎触发价",
             "到期赎回价",
+            "纯债价值",
             "开始转股日",
+            "上市日期",
             "申购日期",
         ]
     ]
@@ -269,8 +271,9 @@ def bond_cov_comparison() -> pd.DataFrame:
 
 
 if __name__ == "__main__":
-    bond_zh_hs_cov_daily_df = bond_zh_hs_cov_daily(symbol="sh113542")
+    bond_zh_hs_cov_daily_df = bond_zh_hs_cov_daily(symbol="sz123111")
     print(bond_zh_hs_cov_daily_df)
+
     bond_zh_hs_cov_spot_df = bond_zh_hs_cov_spot()
     print(bond_zh_hs_cov_spot_df)
 
