@@ -5,7 +5,6 @@ Date: 2022/8/25 18:33
 Desc: 判分主类，主要提供判分及保存
 """
 import os
-import json
 import sys
 from typing import Any
 
@@ -36,6 +35,7 @@ class Score:
     def get_user_name(cls):
         # 获取 Ubuntu 系统的用户名
         user_name = sys.path[0].split("/")[-1].split("-")[-1]
+        print(sys.path)
         return user_name
 
     def get_answer(self, file_name: str = "answer"):
